==> jupyterlab_email-0.2.1.tar.gz: package/lib/index.js <==
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const application_1 = require("@jupyterlab/application");
const apputils_1 = require("@jupyterlab/apputils");
const coreutils_1 = require("@jupyterlab/coreutils");
const docmanager_1 = require("@jupyterlab/docmanager");
const widgets_1 = require("@lumino/widgets");
const filebrowser_1 = require("@jupyterlab/filebrowser");
const launcher_1 = require("@jupyterlab/launcher");
const mainmenu_1 = require("@jupyterlab/mainmenu");
const widgets_2 = require("@lumino/widgets");
const requests_helper_1 = require("requests-helper");
require("../style/index.css");
// tslint:disable: variable-name
const extension = {
    activate,
    autoStart: true,
    id: "jupyterlab_email",
    optional: [launcher_1.ILauncher],
    requires: [docmanager_1.IDocumentManager, apputils_1.ICommandPalette, application_1.ILayoutRestorer, mainmenu_1.IMainMenu, filebrowser_1.IFileBrowserFactory],
};
class SendEmailWidget extends widgets_2.Widget {
    constructor(accounts = [], hide_code = false, account_name = "", templates = [], signatures = [], headers = [], footers = []) {
        const body = document.createElement("div");
        body.style.display = "flex";
        body.style.flexDirection = "column";
        body.classList.add("jupyterlab_email_form");
        const basic = document.createElement("div");
        basic.style.flex = "1";
        body.appendChild(basic);
        basic.appendChild(Private.buildLabel("Type:"));
        basic.appendChild(Private.buildSelect(["Email", "HTML Attachment", "PDF Attachment"], "type", "Email"));
        basic.appendChild(Private.buildLabel("Code or no Code:"));
        basic.appendChild(Private.buildSelect(["Code", "No code"], "code", "No code"));
        basic.appendChild(Private.buildLabel("Send email to:"));
        basic.appendChild(Private.buildTextarea("list, of, emails, default is to self"));
        basic.appendChild(Private.buildLabel("Email Subject:"));
        basic.appendChild(Private.buildTextarea("Subject of email"));
        /* Advanced options */
        const advanced = document.createElement("div");
        advanced.style.flex = "1";
        const advanced_label = document.createElement("label");
        advanced_label.textContent = "Advanced";
        const advanced_button_open = document.createElement("button");
        const advanced_span_open = document.createElement("span");
        const advanced_button_close = document.createElement("button");
        const advanced_span_close = document.createElement("span");
        advanced_button_open.classList.add("jp-ToolbarButtonComponent");
        advanced_button_close.classList.add("jp-ToolbarButtonComponent");
        advanced_button_open.appendChild(advanced_span_open);
        advanced_button_close.appendChild(advanced_span_close);
        advanced_span_open.classList.add("jupyterlab_email_open");
        advanced_span_open.classList.add("jp-Icon");
        advanced_span_open.classList.add("jp-Icon-16");
        advanced_span_close.classList.add("jupyterlab_email_close");
        advanced_span_close.classList.add("jp-Icon");
        advanced_span_close.classList.add("jp-Icon-16");
        body.appendChild(advanced_label);
        body.appendChild(advanced_button_open);
        body.appendChild(advanced_button_close);
        body.appendChild(advanced);
        advanced.style.display = "none";
        advanced_button_open.style.display = "block";
        advanced_button_close.style.display = "none";
        advanced_button_open.onclick = () => {
            advanced.style.display = "block";
            advanced_button_open.style.display = "none";
            advanced_button_close.style.display = "block";
        };
        advanced_button_close.onclick = () => {
            advanced.style.display = "none";
            advanced_button_open.style.display = "block";
            advanced_button_close.style.display = "none";
        };
        if (accounts.length > 0) {
            advanced.appendChild(Private.buildLabel("Account:"));
            advanced.appendChild(Private.buildSelect(accounts, "accounts", account_name));
        }
        advanced.appendChild(Private.buildLabel("Also attach as:"));
        advanced.appendChild(Private.buildSelect(["None", "PDF", "HTML", "Both"], "attach", "None"));
        if (templates.length > 0) {
            advanced.appendChild(Private.buildLabel("Template:"));
            advanced.appendChild(Private.buildSelect(templates, "templates"));
        }
        if (signatures.length > 0) {
            advanced.appendChild(Private.buildLabel("Signature:"));
            advanced.appendChild(Private.buildSelect(signatures, "signatures"));
        }
        if (headers.length > 0) {
            advanced.appendChild(Private.buildLabel("Header:"));
            advanced.appendChild(Private.buildSelect(headers, "headers"));
        }
        if (footers.length > 0) {
            advanced.appendChild(Private.buildLabel("Footer:"));
            advanced.appendChild(Private.buildSelect(footers, "footers"));
        }
        super({ node: body });
    }
    getCode() {
        return this.codeNode.value;
    }
    getEmail() {
        return this.emailNode.value;
    }
    getType() {
        return this.typeNode.value;
    }
    getTo() {
        return this.toNode.value;
    }
    getSubject() {
        return this.subjectNode.value;
    }
    getAlsoAttach() {
        return this.alsoAttachNode.value;
    }
    getTemplate() {
        return this.templateNode ? this.templateNode.value : "";
    }
    getSignature() {
        return this.signatureNode ? this.signatureNode.value : "";
    }
    getHeader() {
        return this.headerNode ? this.headerNode.value : "";
    }
    getFooter() {
        return this.footerNode ? this.footerNode.value : "";
    }
    get typeNode() {
        return this.node.getElementsByTagName("select")[0];
    }
    get codeNode() {
        return this.node.getElementsByTagName("select")[1];
    }
    get emailNode() {
        return this.node.getElementsByTagName("select")[2];
    }
    get toNode() {
        return this.node.getElementsByTagName("textarea")[0];
    }
    get subjectNode() {
        return this.node.getElementsByTagName("textarea")[1];
    }
    get alsoAttachNode() {
        return this.node.getElementsByTagName("select")[3];
    }
    get templateNode() {
        return this.node.querySelector("select.templates");
    }
    get signatureNode() {
        return this.node.querySelector("select.signatures");
    }
    get headerNode() {
        return this.node.querySelector("select.headers");
    }
    get footerNode() {
        return this.node.querySelector("select.footers");
    }
}
exports.SendEmailWidget = SendEmailWidget;
function activate(app, docManager, palette, restorer, mainMenu, browser, launcher) {
    const commands = app.commands;
    const all_emails1 = [];
    const all_accounts = [];
    const all_templates = [];
    const all_signatures = [];
    const all_headers = [];
    const all_footers = [];
    let loaded = false;
    // grab templates from serverextension
    requests_helper_1.request("get", coreutils_1.PageConfig.getBaseUrl() + "email/get").then((res) => {
        if (res.ok) {
            const info = res.json();
            for (const template of info.templates) {
                all_templates.push(template);
            }
            for (const signature of info.signatures) {
                all_signatures.push(signature);
            }
            for (const header of info.headers) {
                all_headers.push(header);
            }
            for (const footer of info.footers) {
                all_footers.push(footer);
            }
            for (const email of info.emails) {
                const command1 = "send-email:" + email;
                all_accounts.push(email);
                all_emails1.push(command1);
                const send_widget = new SendEmailWidget(all_accounts, false, email, all_templates, all_signatures, all_headers, all_footers);
                app.commands.addCommand(command1, {
                    execute: () => {
                        apputils_1.showDialog({
                            body: send_widget,
                            buttons: [apputils_1.Dialog.cancelButton(), apputils_1.Dialog.okButton({ label: "Ok" })],
                            title: "Send email:",
                        }).then((result) => {
                            if (result.button.label === "Cancel") {
                                return;
                            }
                            const folder = browser.defaultBrowser.model.path || "";
                            const context = docManager.contextForWidget(app.shell.currentWidget);
                            const type = send_widget.getType();
                            // tslint:disable-next-line: no-shadowed-variable
                            const email = send_widget.getEmail();
                            const code = send_widget.getCode();
                            const to = send_widget.getTo();
                            const subject = send_widget.getSubject();
                            const also_attach = send_widget.getAlsoAttach();
                            const template = send_widget.getTemplate();
                            const signature = send_widget.getSignature();
                            const header = send_widget.getHeader();
                            const footer = send_widget.getFooter();
                            let path = "";
                            let model = {};
                            if (context) {
                                path = context.path;
                                model = context.model.toJSON();
                            }
                            return new Promise((resolve) => {
                                requests_helper_1.request("post", coreutils_1.PageConfig.getBaseUrl() + "email/run", {}, { also_attach,
                                    code,
                                    email,
                                    folder,
                                    footer,
                                    header,
                                    model,
                                    path,
                                    signature,
                                    subject,
                                    template,
                                    to,
                                    type,
                                }).then(
                                // tslint:disable-next-line: no-shadowed-variable
                                (res) => {
                                    if (res.ok) {
                                        apputils_1.showDialog({
                                            buttons: [apputils_1.Dialog.okButton({ label: "Ok" })],
                                            title: "Mail sent!",
                                        }).then(() => { resolve(); });
                                    }
                                    else {
                                        apputils_1.showDialog({
                                            body: "Check the Jupyter logs for the exception.",
                                            buttons: [apputils_1.Dialog.okButton({ label: "Ok" })],
                                            title: "Something went wrong!",
                                        }).then(() => { resolve(); });
                                    }
                                });
                            });
                        });
                    },
                    isEnabled: () => {
                        if (app.shell.currentWidget &&
                            docManager.contextForWidget(app.shell.currentWidget) &&
                            docManager.contextForWidget(app.shell.currentWidget).model) {
                            return true;
                        }
                        return false;
                    },
                    label: command1,
                });
                palette.addItem({ command: command1, category: "Email" });
                const menu = new widgets_1.Menu({ commands });
                menu.title.label = "Send Emails";
                app.restored.then(() => {
                    all_emails1.forEach((command) => {
                        menu.addItem({ command, args: {} });
                    });
                    if (mainMenu && !loaded) {
                        loaded = true;
                        mainMenu.fileMenu.addGroup([{ type: "submenu", submenu: menu }], 11);
                    }
                });
            }
        }
    });
    // tslint:disable-next-line:no-console
    console.log("JupyterLab extension jupyterlab_email is activated!");
}
exports._activate = activate;
exports.default = extension;
// tslint:disable-next-line:no-namespace
var Private;
(function (Private) {
    const default_none = document.createElement("option");
    default_none.selected = false;
    default_none.disabled = true;
    default_none.hidden = false;
    default_none.style.display = "none";
    default_none.value = "";
    function buildLabel(text) {
        const label = document.createElement("label");
        label.textContent = text;
        return label;
    }
    Private.buildLabel = buildLabel;
    function buildTextarea(text) {
        const area = document.createElement("textarea");
        area.placeholder = text;
        area.style.marginBottom = "15px";
        return area;
    }
    Private.buildTextarea = buildTextarea;
    function buildSelect(list, _class = "", def) {
        const select = document.createElement("select");
        select.classList.add(_class);
        select.appendChild(default_none);
        for (const x of list) {
            const option = document.createElement("option");
            option.value = x;
            option.textContent = x;
            select.appendChild(option);
            if (def && x === def) {
                option.selected = true;
            }
        }
        select.style.marginBottom = "15px";
        select.style.minHeight = "25px";
        return select;
    }
    Private.buildSelect = buildSelect;
})(Private || (Private = {}));

==> jupyterlab_email-0.2.4.tar.gz: package/lib/index.js <==
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const application_1 = require("@jupyterlab/application");
const apputils_1 = require("@jupyterlab/apputils");
const coreutils_1 = require("@jupyterlab/coreutils");
const docmanager_1 = require("@jupyterlab/docmanager");
const widgets_1 = require("@lumino/widgets");
const filebrowser_1 = require("@jupyterlab/filebrowser");
const launcher_1 = require("@jupyterlab/launcher");
const mainmenu_1 = require("@jupyterlab/mainmenu");
const widgets_2 = require("@lumino/widgets");
const requests_helper_1 = require("requests-helper");
require("../style/index.css");
// tslint:disable: variable-name
const extension = {
    activate,
    autoStart: true,
    id: "jupyterlab_email",
    optional: [launcher_1.ILauncher],
    requires: [docmanager_1.IDocumentManager, apputils_1.ICommandPalette, application_1.ILayoutRestorer, mainmenu_1.IMainMenu, filebrowser_1.IFileBrowserFactory],
};
class SendEmailWidget extends widgets_2.Widget {
    constructor(accounts = [], hide_code = false, account_name = "", templates = [], signatures = [], headers = [], footers = [], user_templates = [], postprocessors = []) {
        const body = document.createElement("div");
        body.style.display = "flex";
        body.style.flexDirection = "column";
        body.classList.add("jupyterlab_email_form");
        const basic = document.createElement("div");
        basic.style.flex = "1";
        body.appendChild(basic);
        basic.appendChild(Private.buildLabel("Type:"));
        basic.appendChild(Private.buildSelect(["Email", "HTML Attachment", "PDF Attachment"], "type", "Email"));
        basic.appendChild(Private.buildLabel("Code or no Code:"));
        basic.appendChild(Private.buildSelect(["Code", "No code"], "code", "No code"));
        basic.appendChild(Private.buildLabel("Send email to:"));
        basic.appendChild(Private.buildTextarea("list, of, emails, default is to self"));
        basic.appendChild(Private.buildLabel("Email Subject:"));
        basic.appendChild(Private.buildTextarea("Subject of email"));
        /* Advanced options */
        const advanced = document.createElement("div");
        advanced.style.flex = "1";
        const expand_div = document.createElement("div");
        expand_div.style.display = "flex";
        expand_div.style.flexDirection = "row";
        const advanced_label = document.createElement("label");
        advanced_label.textContent = "Advanced";
        expand_div.appendChild(advanced_label);
        const advanced_button_open = document.createElement("button");
        const advanced_span_open = document.createElement("span");
        const advanced_button_close = document.createElement("button");
        const advanced_span_close = document.createElement("span");
        advanced_button_open.classList.add("jp-ToolbarButtonComponent");
        advanced_button_close.classList.add("jp-ToolbarButtonComponent");
        advanced_button_open.appendChild(advanced_span_open);
        advanced_button_close.appendChild(advanced_span_close);
        advanced_span_open.classList.add("jupyterlab_email_open");
        advanced_span_close.classList.add("jupyterlab_email_close");
        expand_div.appendChild(advanced_button_open);
        expand_div.appendChild(advanced_button_close);
        body.appendChild(expand_div);
        body.appendChild(advanced);
        advanced.style.display = "none";
        advanced_button_open.style.display = "block";
        advanced_button_close.style.display = "none";
        advanced_button_open.onclick = () => {
            advanced.style.display = "block";
            advanced_button_open.style.display = "none";
            advanced_button_close.style.display = "block";
        };
        advanced_button_close.onclick = () => {
            advanced.style.display = "none";
            advanced_button_open.style.display = "block";
            advanced_button_close.style.display = "none";
        };
        if (accounts.length > 0) {
            advanced.appendChild(Private.buildLabel("Account:"));
            advanced.appendChild(Private.buildSelect(accounts, "accounts", account_name));
        }
        advanced.appendChild(Private.buildLabel("Also attach as:"));
        advanced.appendChild(Private.buildSelect(["None", "PDF", "HTML", "Both"], "attach", "None"));
        if (templates.length > 0) {
            advanced.appendChild(Private.buildLabel("Template:"));
            advanced.appendChild(Private.buildSelect(templates, "templates"));
        }
        if (user_templates.length > 0) {
            advanced.appendChild(Private.buildLabel("User Templates (Overrides 'builtin' template choice):"));
            advanced.appendChild(Private.buildSelect(user_templates, "user_template"));
        }
        if (signatures.length > 0) {
            advanced.appendChild(Private.buildLabel("Signature:"));
            advanced.appendChild(Private.buildSelect(signatures, "signatures"));
        }
        if (headers.length > 0) {
            advanced.appendChild(Private.buildLabel("Header:"));
            advanced.appendChild(Private.buildSelect(headers, "headers"));
        }
        if (footers.length > 0) {
            advanced.appendChild(Private.buildLabel("Footer:"));
            advanced.appendChild(Private.buildSelect(footers, "footers"));
        }
        if (postprocessors.length > 0) {
            advanced.appendChild(Private.buildLabel("Post Processors:"));
            advanced.appendChild(Private.buildSelect(postprocessors, "postprocessor"));
        }
        super({ node: body });
    }
    getCode() {
        return this.codeNode.value;
    }
    getEmail() {
        return this.emailNode.value;
    }
    getType() {
        return this.typeNode.value;
    }
    getTo() {
        return this.toNode.value;
    }
    getSubject() {
        return this.subjectNode.value;
    }
    getAlsoAttach() {
        return this.alsoAttachNode.value;
    }
    getTemplate() {
        return this.templateNode ? this.templateNode.value : "";
    }
    getSignature() {
        return this.signatureNode ? this.signatureNode.value : "";
    }
    getHeader() {
        return this.headerNode ? this.headerNode.value : "";
    }
    getFooter() {
        return this.footerNode ? this.footerNode.value : "";
    }
    getUserTemplate() {
        return this.userTemplateNode ? this.userTemplateNode.value : "";
    }
    getPostprocessor() {
        return this.userTemplateNode ? this.userTemplateNode.value : "";
    }
    get typeNode() {
        return this.node.getElementsByTagName("select")[0];
    }
    get codeNode() {
        return this.node.getElementsByTagName("select")[1];
    }
    get emailNode() {
        return this.node.getElementsByTagName("select")[2];
    }
    get toNode() {
        return this.node.getElementsByTagName("textarea")[0];
    }
    get subjectNode() {
        return this.node.getElementsByTagName("textarea")[1];
    }
    get alsoAttachNode() {
        return this.node.getElementsByTagName("select")[3];
    }
    get templateNode() {
        return this.node.querySelector("select.templates");
    }
    get signatureNode() {
        return this.node.querySelector("select.signatures");
    }
    get headerNode() {
        return this.node.querySelector("select.headers");
    }
    get footerNode() {
        return this.node.querySelector("select.footers");
    }
    get userTemplateNode() {
        return this.node.querySelector("select.user_template");
    }
    get postprocessorNode() {
        return this.node.querySelector("select.postprocessor");
    }
}
exports.SendEmailWidget = SendEmailWidget;
function activate(app, docManager, palette, restorer, mainMenu, browser, launcher) {
    const commands = app.commands;
    const all_emails1 = [];
    const all_accounts = [];
    const all_templates = [];
    const all_user_templates = [];
    const all_signatures = [];
    const all_headers = [];
    const all_footers = [];
    let loaded = false;
    // grab templates from serverextension
    requests_helper_1.request("get", coreutils_1.PageConfig.getBaseUrl() + "email/get").then((res) => {
        if (res.ok) {
            const info = res.json();
            for (const template of info.templates) {
                all_templates.push(template);
            }
            for (const template of info.user_templates) {
                all_user_templates.push(template);
            }
            for (const signature of info.signatures) {
                all_signatures.push(signature);
            }
            for (const header of info.headers) {
                all_headers.push(header);
            }
            for (const footer of info.footers) {
                all_footers.push(footer);
            }
            for (const email of info.emails) {
                const command1 = "send-email:" + email;
                all_accounts.push(email);
                all_emails1.push(command1);
                const send_widget = new SendEmailWidget(all_accounts, false, email, all_templates, all_signatures, all_headers, all_footers, all_user_templates);
                app.commands.addCommand(command1, {
                    execute: () => {
                        apputils_1.showDialog({
                            body: send_widget,
                            buttons: [apputils_1.Dialog.cancelButton(), apputils_1.Dialog.okButton({ label: "Ok" })],
                            title: "Send email:",
                        }).then((result) => {
                            if (result.button.label === "Cancel") {
                                return;
                            }
                            const folder = browser.defaultBrowser.model.path || "";
                            const context = docManager.contextForWidget(app.shell.currentWidget);
                            const type = send_widget.getType();
                            // eslint-disable-next-line no-shadow
                            const email = send_widget.getEmail();
                            const code = send_widget.getCode();
                            const to = send_widget.getTo();
                            const subject = send_widget.getSubject();
                            const also_attach = send_widget.getAlsoAttach();
                            const template = send_widget.getTemplate();
                            const user_template = send_widget.getUserTemplate();
                            const signature = send_widget.getSignature();
                            const header = send_widget.getHeader();
                            const footer = send_widget.getFooter();
                            const postprocessor = send_widget.getPostprocessor();
                            let path = "";
                            let model = {};
                            if (context) {
                                path = context.path;
                                model = context.model.toJSON();
                            }
                            return new Promise((resolve) => {
                                requests_helper_1.request("post", coreutils_1.PageConfig.getBaseUrl() + "email/run", {}, { also_attach,
                                    code,
                                    email,
                                    folder,
                                    footer,
                                    header,
                                    model,
                                    path,
                                    postprocessor,
                                    signature,
                                    subject,
                                    template,
                                    to,
                                    type,
                                    user_template,
                                }, { timeout: 30000 }).then(
                                // eslint-disable-next-line no-shadow
                                (res) => {
                                    if (res.ok) {
                                        apputils_1.showDialog({
                                            buttons: [apputils_1.Dialog.okButton({ label: "Ok" })],
                                            title: "Mail sent!",
                                        }).then(() => {
                                            resolve();
                                        });
                                    }
                                    else {
                                        apputils_1.showDialog({
                                            body: "Check the Jupyter logs for the exception.",
                                            buttons: [apputils_1.Dialog.okButton({ label: "Ok" })],
                                            title: "Something went wrong!",
                                        }).then(() => {
                                            resolve();
                                        });
                                    }
                                });
                            });
                        });
                    },
                    isEnabled: () => {
                        if (app.shell.currentWidget &&
                            docManager.contextForWidget(app.shell.currentWidget) &&
                            docManager.contextForWidget(app.shell.currentWidget).model) {
                            return true;
                        }
                        return false;
                    },
                    label: command1,
                });
                palette.addItem({ command: command1, category: "Email" });
                const menu = new widgets_1.Menu({ commands });
                menu.title.label = "Send Emails";
                app.restored.then(() => {
                    all_emails1.forEach((command) => {
                        menu.addItem({ command, args: {} });
                    });
                    if (mainMenu && !loaded) {
                        loaded = true;
                        mainMenu.fileMenu.addGroup([{ type: "submenu", submenu: menu }], 11);
                    }
                });
            }
        }
    });
    // eslint-disable-next-line no-console
    console.log("JupyterLab extension jupyterlab_email is activated!");
}
exports._activate = activate;
exports.default = extension;
// eslint-disable-next-line @typescript-eslint/no-namespace
var Private;
(function (Private) {
    const default_none = document.createElement("option");
    default_none.selected = false;
    default_none.disabled = true;
    default_none.hidden = false;
    default_none.style.display = "none";
    default_none.value = "";
    function buildLabel(text) {
        const label = document.createElement("label");
        label.textContent = text;
        return label;
    }
    Private.buildLabel = buildLabel;
    function buildTextarea(text) {
        const area = document.createElement("textarea");
        area.placeholder = text;
        area.style.marginBottom = "15px";
        return area;
    }
    Private.buildTextarea = buildTextarea;
    function buildSelect(list, _class = "", def) {
        const select = document.createElement("select");
        select.classList.add(_class);
        select.appendChild(default_none);
        for (const x of list) {
            const option = document.createElement("option");
            option.value = x;
            option.textContent = x;
            select.appendChild(option);
            if (def && x === def) {
                option.selected = true;
            }
        }
        select.style.marginBottom = "15px";
        select.style.minHeight = "25px";
        return select;
    }
    Private.buildSelect = buildSelect;
})(Private || (Private = {}));
